@@ -30,6 +30,7 @@
 #include "keys.h"
 #include "preferences.h"
 #include "track.h"
+#include "misc.h"
 
 static void	gnome_volume_control_element_class_init	(GnomeVolumeControlElementClass *klass);
 static void	gnome_volume_control_element_init	(GnomeVolumeControlElement *el);
@@ -123,6 +124,9 @@ gnome_volume_control_element_dispose (GObject *object)
   }
 
   if (el->mixer) {
+    /* remove g_timeout_add() mainloop handlers */
+    gnome_volume_control_element_change (el, NULL);
+    gst_element_set_state (GST_ELEMENT (el->mixer), GST_STATE_NULL);
     gst_object_unref (GST_OBJECT (el->mixer));
     el->mixer = NULL;
   }
@@ -166,19 +170,6 @@ gnome_volume_control_element_whitelist (GstMixerTrack *track,
  * Hide/show notebook page.
  */
 
-static gint
-get_page_num (GstMixerTrack *track)
-{
-  if (GST_IS_MIXER_OPTIONS (track))
-    return 3;
-  else if (track->num_channels == 0)
-    return 2;
-  else if (track->flags & GST_MIXER_TRACK_INPUT)
-    return 1;
-  else
-    return 0;
-}
-
 static void
 update_tab_visibility (GnomeVolumeControlElement *el, gint page)
 {
@@ -228,8 +219,8 @@ gnome_volume_control_element_change (GnomeVolumeControlElement *el,
   } content[4] = {
     { _("Playback"), NULL, NULL, NULL, FALSE, 0, 5, 1,
       gnome_volume_control_track_add_playback },
-    { _("Capture"),  NULL, NULL, NULL, FALSE, 0, 5, 1,
-      gnome_volume_control_track_add_capture },
+    { _("Recording"),  NULL, NULL, NULL, FALSE, 0, 5, 1,
+      gnome_volume_control_track_add_recording },
     { _("Switches"), NULL, NULL, NULL, FALSE, 0, 1, 3,
       gnome_volume_control_track_add_switch },
     { _("Options"),  NULL, NULL, NULL, FALSE, 0, 1, 3,
@@ -240,9 +231,6 @@ gnome_volume_control_element_change (GnomeVolumeControlElement *el,
   const GList *item;
   GstMixer *mixer;
 
-  g_return_if_fail (GST_IS_MIXER (element));
-  mixer = GST_MIXER (element);
-
   /* remove old pages */
   while (gtk_notebook_get_n_pages (GTK_NOTEBOOK (el)) > 0) {
     gtk_notebook_remove_page (GTK_NOTEBOOK (el), 0);
@@ -260,6 +248,11 @@ gnome_volume_control_element_change (GnomeVolumeControlElement *el,
       gnome_volume_control_track_free (trkw);
     }
   }
+  if (!element)
+    return;
+
+  g_return_if_fail (GST_IS_MIXER (element));
+  mixer = GST_MIXER (element);
   gst_object_replace ((GstObject **) &el->mixer, GST_OBJECT (element));
 
   /* content pages */
